#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_zmi.layer import IAdminLayer
from pyramid.interfaces import IView

# import packages
from pyams_i18n.schema import I18nTextLineField
from pyams_template.template import layout_config
from zope.interface import Interface, Attribute
from zope.schema import TextLine, Choice, Bool

from pyams_zmi import _


@layout_config(template='templates/admin-layout.pt', layer=IAdminLayer)
class IAdminView(IView):
    """Marker interface for administration views"""


class IPropertiesEditForm(Interface):
    """Properties edit form marker interface"""


class IZMIConfiguration(Interface):
    """Static configuration interface

    These configuration options are used by default presentation layout
    """

    application_package = TextLine(title=_("Main package"),
                                   description=_("This package is used to get current application version"),
                                   default='pyams_skin',
                                   required=False)

    application_name = TextLine(title=_("Application name"),
                                description=_("This name is used to display application version"),
                                default='PyAMS',
                                required=False)

    inner_package = TextLine(title=_("Inner package"),
                             description=_("This is another important package displayed in application version"),
                             default='pyams_skin',
                             required=False)

    inner_package_name = TextLine(title=_("Inner package name"),
                                  description=_("Package name used to display application version"),
                                  required=False)

    version = Attribute("Application version")

    version_location = Choice(title=_("Version location"),
                              description=_("Position of version label"),
                              required=False,
                              values=(u'menus', u'shortcuts'),
                              default=u'menus')

    include_header = Bool(title=_("Include header?"),
                          required=True,
                          default=True)

    fixed_header = Bool(title=_("Fixed header?"),
                        required=True,
                        default=True)

    include_top_links = Bool(title=_("Include top links?"),
                             required=True,
                             default=True)

    include_site_search = Bool(title=_("Include site search?"),
                               required=False,
                               default=True)

    site_search_placeholder = I18nTextLineField(title=_("Site search placeholder"),
                                                required=False,
                                                default=_("Search..."))

    site_search_handler = TextLine(title=_("Site search handler"),
                                   required=False,
                                   default="#search.html")

    include_mobile_search = Bool(title=_("Include mobile search?"),
                                 required=False,
                                 default=True)

    mobile_search_placeholder = I18nTextLineField(title=_("Mobile search placeholder"),
                                                  required=False,
                                                  default=_("Search..."))

    mobile_search_handler = TextLine(title=_("Mobile search handler"),
                                     required=False,
                                     default='#search.html')

    include_user_activity = Bool(title=_("Include user dropdown window?"),
                                 required=True,
                                 default=True)

    include_user_shortcuts = Bool(title=_("Include user shortcuts?"),
                                  required=True,
                                  default=True)

    include_logout_button = Bool(title=_("Include logout button?"),
                                 required=True,
                                 default=True)

    include_minify_button = Bool(title=_("Include minify button?"),
                                 required=True,
                                 default=True)

    include_flags = Bool(title=_("Include flags menu?"),
                         required=True,
                         default=False)

    include_menus = Bool(title=_("Include main menus?"),
                         required=True,
                         default=True)

    fixed_navigation = Bool(title=_("Fixed menus?"),
                            required=True,
                            default=True)

    accordion_menus = Bool(title=_("Display menus as accordion?"),
                           required=True,
                           default=True)

    include_ribbon = Bool(title=_("Include ribbon?"),
                          required=True,
                          default=True)

    fixed_ribbon = Bool(title=_("Fixed ribbon?"),
                        required=True,
                        default=True)

    include_reload_button = Bool(title=_("Include reload button?"),
                                 required=True,
                                 default=False)

    base_body_css_class = TextLine(title=_("Base body CSS class"),
                                   required=False)

    body_css_class = Attribute("HTML body CSS class")